from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FeCls:
	"""Fe commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fe", core, parent)

	def set(self, areg_mapping_ctf: enums.AregChanMappingGui, mappingChannel=repcap.MappingChannel.Default) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:MAPPing<CH>:FE \n
		Snippet: driver.source.areGenerator.mapping.fe.set(areg_mapping_ctf = enums.AregChanMappingGui.IFONly, mappingChannel = repcap.MappingChannel.Default) \n
		No command help available \n
			:param areg_mapping_ctf: NONE| IFONly| TRX1| TRX2| TRX3| TRX4| QAT1CH1| QAT1CH2| QAT1CH3| QAT1CH4| QAT1CH5| QAT1CH6| QAT1CH7| QAT1CH8| QAT2CH1| QAT2CH2| QAT2CH3| QAT2CH4| QAT2CH5| QAT2CH6| QAT2CH7| QAT2CH8| QAT3CH1| QAT3CH2| QAT3CH3| QAT3CH4| QAT3CH5| QAT3CH6| QAT3CH7| QAT3CH8| QAT4CH1| QAT4CH2| QAT4CH3| QAT4CH4| QAT4CH5| QAT4CH6| QAT4CH7| QAT4CH8| QAT5CH1| QAT5CH2| QAT5CH3| QAT5CH4| QAT5CH5| QAT5CH6| QAT5CH7| QAT5CH8| QAT6CH1| QAT6CH2| QAT6CH3| QAT6CH4| QAT6CH5| QAT6CH6| QAT6CH7| QAT6CH8| QAT7CH1| QAT7CH2| QAT7CH3| QAT7CH4| QAT7CH5| QAT7CH6| QAT7CH7| QAT7CH8| QAT8CH1| QAT8CH2| QAT8CH3| QAT8CH4| QAT8CH5| QAT8CH6| QAT8CH7| QAT8CH8
			:param mappingChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mapping')
		"""
		param = Conversions.enum_scalar_to_str(areg_mapping_ctf, enums.AregChanMappingGui)
		mappingChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(mappingChannel, repcap.MappingChannel)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:MAPPing{mappingChannel_cmd_val}:FE {param}')

	# noinspection PyTypeChecker
	def get(self, mappingChannel=repcap.MappingChannel.Default) -> enums.AregChanMappingGui:
		"""SCPI: [SOURce<HW>]:AREGenerator:MAPPing<CH>:FE \n
		Snippet: value: enums.AregChanMappingGui = driver.source.areGenerator.mapping.fe.get(mappingChannel = repcap.MappingChannel.Default) \n
		No command help available \n
			:param mappingChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mapping')
			:return: areg_mapping_ctf: NONE| IFONly| TRX1| TRX2| TRX3| TRX4| QAT1CH1| QAT1CH2| QAT1CH3| QAT1CH4| QAT1CH5| QAT1CH6| QAT1CH7| QAT1CH8| QAT2CH1| QAT2CH2| QAT2CH3| QAT2CH4| QAT2CH5| QAT2CH6| QAT2CH7| QAT2CH8| QAT3CH1| QAT3CH2| QAT3CH3| QAT3CH4| QAT3CH5| QAT3CH6| QAT3CH7| QAT3CH8| QAT4CH1| QAT4CH2| QAT4CH3| QAT4CH4| QAT4CH5| QAT4CH6| QAT4CH7| QAT4CH8| QAT5CH1| QAT5CH2| QAT5CH3| QAT5CH4| QAT5CH5| QAT5CH6| QAT5CH7| QAT5CH8| QAT6CH1| QAT6CH2| QAT6CH3| QAT6CH4| QAT6CH5| QAT6CH6| QAT6CH7| QAT6CH8| QAT7CH1| QAT7CH2| QAT7CH3| QAT7CH4| QAT7CH5| QAT7CH6| QAT7CH7| QAT7CH8| QAT8CH1| QAT8CH2| QAT8CH3| QAT8CH4| QAT8CH5| QAT8CH6| QAT8CH7| QAT8CH8"""
		mappingChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(mappingChannel, repcap.MappingChannel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:AREGenerator:MAPPing{mappingChannel_cmd_val}:FE?')
		return Conversions.str_to_scalar_enum(response, enums.AregChanMappingGui)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DeviceCls:
	"""Device commands group definition. 3 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("device", core, parent)

	@property
	def settings(self):
		"""settings commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_settings'):
			from .Settings import SettingsCls
			self._settings = SettingsCls(self._core, self._cmd_group)
		return self._settings

	def preset(self) -> None:
		"""SCPI: DEVice:PRESet \n
		Snippet: driver.device.preset() \n
		Presets all parameters which are not related to the signal path, including the LF generator. \n
		"""
		self._core.io.write(f'DEVice:PRESet')

	def preset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: DEVice:PRESet \n
		Snippet: driver.device.preset_with_opc() \n
		Presets all parameters which are not related to the signal path, including the LF generator. \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsAreg800.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'DEVice:PRESet', opc_timeout_ms)

	def clone(self) -> 'DeviceCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DeviceCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AttenuationCls:
	"""Attenuation commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("attenuation", core, parent)

	def set(self, areg_cable_corr_at: float, trxFrontent=repcap.TrxFrontent.Default, connector=repcap.Connector.Default, txIndexNull=repcap.TxIndexNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:FRONtend:TRX<CH>:CABLecorr:CONNector<DI>:TX<ST0>:USER:ATTenuation \n
		Snippet: driver.source.areGenerator.frontend.trx.cableCorr.connector.tx.user.attenuation.set(areg_cable_corr_at = 1.0, trxFrontent = repcap.TrxFrontent.Default, connector = repcap.Connector.Default, txIndexNull = repcap.TxIndexNull.Default) \n
		No command help available \n
			:param areg_cable_corr_at: float Range: 0 to 50
			:param trxFrontent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trx')
			:param connector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Connector')
			:param txIndexNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Tx')
		"""
		param = Conversions.decimal_value_to_str(areg_cable_corr_at)
		trxFrontent_cmd_val = self._cmd_group.get_repcap_cmd_value(trxFrontent, repcap.TrxFrontent)
		connector_cmd_val = self._cmd_group.get_repcap_cmd_value(connector, repcap.Connector)
		txIndexNull_cmd_val = self._cmd_group.get_repcap_cmd_value(txIndexNull, repcap.TxIndexNull)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:FRONtend:TRX{trxFrontent_cmd_val}:CABLecorr:CONNector{connector_cmd_val}:TX{txIndexNull_cmd_val}:USER:ATTenuation {param}')

	def get(self, trxFrontent=repcap.TrxFrontent.Default, connector=repcap.Connector.Default, txIndexNull=repcap.TxIndexNull.Default) -> float:
		"""SCPI: [SOURce<HW>]:AREGenerator:FRONtend:TRX<CH>:CABLecorr:CONNector<DI>:TX<ST0>:USER:ATTenuation \n
		Snippet: value: float = driver.source.areGenerator.frontend.trx.cableCorr.connector.tx.user.attenuation.get(trxFrontent = repcap.TrxFrontent.Default, connector = repcap.Connector.Default, txIndexNull = repcap.TxIndexNull.Default) \n
		No command help available \n
			:param trxFrontent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trx')
			:param connector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Connector')
			:param txIndexNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Tx')
			:return: areg_cable_corr_at: float Range: 0 to 50"""
		trxFrontent_cmd_val = self._cmd_group.get_repcap_cmd_value(trxFrontent, repcap.TrxFrontent)
		connector_cmd_val = self._cmd_group.get_repcap_cmd_value(connector, repcap.Connector)
		txIndexNull_cmd_val = self._cmd_group.get_repcap_cmd_value(txIndexNull, repcap.TxIndexNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:AREGenerator:FRONtend:TRX{trxFrontent_cmd_val}:CABLecorr:CONNector{connector_cmd_val}:TX{txIndexNull_cmd_val}:USER:ATTenuation?')
		return Conversions.str_to_float(response)



from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DloggingCls:
	"""Dlogging commands group definition. 9 total commands, 0 Subgroups, 9 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dlogging", core, parent)

	def clear(self) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:DLOGging:CLEar \n
		Snippet: driver.source.areGenerator.dlogging.clear() \n
		Removes all logging information, that is collected in the logging data. Query logging data via the command
		[:SOURce<hw>]:AREGenerator:DLOGging:DATA. \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:DLOGging:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:DLOGging:CLEar \n
		Snippet: driver.source.areGenerator.dlogging.clear_with_opc() \n
		Removes all logging information, that is collected in the logging data. Query logging data via the command
		[:SOURce<hw>]:AREGenerator:DLOGging:DATA. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsAreg800.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:AREGenerator:DLOGging:CLEar', opc_timeout_ms)

	def get_data(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:AREGenerator:DLOGging:DATA \n
		Snippet: value: List[str] = driver.source.areGenerator.dlogging.get_data() \n
		Queries all logging information in the logged data. \n
			:return: areg_dyn_logg_data: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:DLOGging:DATA?')
		return Conversions.str_to_str_list(response)

	# noinspection PyTypeChecker
	def get_level(self) -> enums.AregDynLoggLevel:
		"""SCPI: [SOURce<HW>]:AREGenerator:DLOGging:LEVel \n
		Snippet: value: enums.AregDynLoggLevel = driver.source.areGenerator.dlogging.get_level() \n
		Defines the scope of logged data. Only logging information is collected, that corresponds to this scope. \n
			:return: dyn_logg_level: ALL| EAWarning| ERRor All Logged data includes information on errors, warnings and info messages. EAWarning Logged data includes information on errors and warnings. ERRor Logged data includes information on errors.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:DLOGging:LEVel?')
		return Conversions.str_to_scalar_enum(response, enums.AregDynLoggLevel)

	def set_level(self, dyn_logg_level: enums.AregDynLoggLevel) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:DLOGging:LEVel \n
		Snippet: driver.source.areGenerator.dlogging.set_level(dyn_logg_level = enums.AregDynLoggLevel.ALL) \n
		Defines the scope of logged data. Only logging information is collected, that corresponds to this scope. \n
			:param dyn_logg_level: ALL| EAWarning| ERRor All Logged data includes information on errors, warnings and info messages. EAWarning Logged data includes information on errors and warnings. ERRor Logged data includes information on errors.
		"""
		param = Conversions.enum_scalar_to_str(dyn_logg_level, enums.AregDynLoggLevel)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:DLOGging:LEVel {param}')

	def get_nerror(self) -> int:
		"""SCPI: [SOURce<HW>]:AREGenerator:DLOGging:NERRor \n
		Snippet: value: int = driver.source.areGenerator.dlogging.get_nerror() \n
		Queries the number of errors within the logged data. \n
			:return: dyn_logg_num_of_err: integer Range: 0 to 100
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:DLOGging:NERRor?')
		return Conversions.str_to_int(response)

	def get_ninfo(self) -> int:
		"""SCPI: [SOURce<HW>]:AREGenerator:DLOGging:NINFo \n
		Snippet: value: int = driver.source.areGenerator.dlogging.get_ninfo() \n
		Queries the number of info messages within the logged data. \n
			:return: dyn_logg_num_of_inf: integer Range: 0 to 100
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:DLOGging:NINFo?')
		return Conversions.str_to_int(response)

	def get_nwarning(self) -> int:
		"""SCPI: [SOURce<HW>]:AREGenerator:DLOGging:NWARning \n
		Snippet: value: int = driver.source.areGenerator.dlogging.get_nwarning() \n
		Queries the number of warnings within the logged data. \n
			:return: dyn_logg_num_of_war: integer Range: 0 to 100
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:DLOGging:NWARning?')
		return Conversions.str_to_int(response)

	def get_save(self) -> str:
		"""SCPI: [SOURce<HW>]:AREGenerator:DLOGging:SAVE \n
		Snippet: value: str = driver.source.areGenerator.dlogging.get_save() \n
		Saves logged data to a file with file extension *.csv. The file extension is added automatically. \n
			:return: dyn_logg_save: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:DLOGging:SAVE?')
		return trim_str_response(response)

	def set_save(self, dyn_logg_save: str) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:DLOGging:SAVE \n
		Snippet: driver.source.areGenerator.dlogging.set_save(dyn_logg_save = '1') \n
		Saves logged data to a file with file extension *.csv. The file extension is added automatically. \n
			:param dyn_logg_save: string
		"""
		param = Conversions.value_to_quoted_str(dyn_logg_save)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:DLOGging:SAVE {param}')

	# noinspection PyTypeChecker
	def get_tbase(self) -> enums.AregDynLoggTimeBase:
		"""SCPI: [SOURce<HW>]:AREGenerator:DLOGging:TBASe \n
		Snippet: value: enums.AregDynLoggTimeBase = driver.source.areGenerator.dlogging.get_tbase() \n
		Sets the time base of the logged data. \n
			:return: dyn_logg_time_base: SYSTem| SIMulation
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:DLOGging:TBASe?')
		return Conversions.str_to_scalar_enum(response, enums.AregDynLoggTimeBase)

	def set_tbase(self, dyn_logg_time_base: enums.AregDynLoggTimeBase) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:DLOGging:TBASe \n
		Snippet: driver.source.areGenerator.dlogging.set_tbase(dyn_logg_time_base = enums.AregDynLoggTimeBase.SIMulation) \n
		Sets the time base of the logged data. \n
			:param dyn_logg_time_base: SYSTem| SIMulation
		"""
		param = Conversions.enum_scalar_to_str(dyn_logg_time_base, enums.AregDynLoggTimeBase)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:DLOGging:TBASe {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:AREGenerator:DLOGging:[STATe] \n
		Snippet: value: bool = driver.source.areGenerator.dlogging.get_state() \n
		Activates logging. \n
			:return: dyn_logg_state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:DLOGging:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, dyn_logg_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:DLOGging:[STATe] \n
		Snippet: driver.source.areGenerator.dlogging.set_state(dyn_logg_state = False) \n
		Activates logging. \n
			:param dyn_logg_state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(dyn_logg_state)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:DLOGging:STATe {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SensorCls:
	"""Sensor commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sensor", core, parent)

	def set(self, areg_mapping_mts: enums.AregChanMappingSensor, mappingChannel=repcap.MappingChannel.Default) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:MAPPing<CH>:SENSor \n
		Snippet: driver.source.areGenerator.mapping.sensor.set(areg_mapping_mts = enums.AregChanMappingSensor.NONE, mappingChannel = repcap.MappingChannel.Default) \n
		No command help available \n
			:param areg_mapping_mts: NONE| SEN1| SEN2| SEN4| SEN3| SEN5| SEN6| SEN7| SEN8
			:param mappingChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mapping')
		"""
		param = Conversions.enum_scalar_to_str(areg_mapping_mts, enums.AregChanMappingSensor)
		mappingChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(mappingChannel, repcap.MappingChannel)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:MAPPing{mappingChannel_cmd_val}:SENSor {param}')

	# noinspection PyTypeChecker
	def get(self, mappingChannel=repcap.MappingChannel.Default) -> enums.AregChanMappingSensor:
		"""SCPI: [SOURce<HW>]:AREGenerator:MAPPing<CH>:SENSor \n
		Snippet: value: enums.AregChanMappingSensor = driver.source.areGenerator.mapping.sensor.get(mappingChannel = repcap.MappingChannel.Default) \n
		No command help available \n
			:param mappingChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mapping')
			:return: areg_mapping_mts: NONE| SEN1| SEN2| SEN4| SEN3| SEN5| SEN6| SEN7| SEN8"""
		mappingChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(mappingChannel, repcap.MappingChannel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:AREGenerator:MAPPing{mappingChannel_cmd_val}:SENSor?')
		return Conversions.str_to_scalar_enum(response, enums.AregChanMappingSensor)



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ChannelCls:
	"""Channel commands group definition. 12 total commands, 5 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("channel", core, parent)

	@property
	def bw(self):
		"""bw commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_bw'):
			from .Bw import BwCls
			self._bw = BwCls(self._core, self._cmd_group)
		return self._bw

	@property
	def condition(self):
		"""condition commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_condition'):
			from .Condition import ConditionCls
			self._condition = ConditionCls(self._core, self._cmd_group)
		return self._condition

	@property
	def level(self):
		"""level commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_level'):
			from .Level import LevelCls
			self._level = LevelCls(self._core, self._cmd_group)
		return self._level

	@property
	def optimization(self):
		"""optimization commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_optimization'):
			from .Optimization import OptimizationCls
			self._optimization = OptimizationCls(self._core, self._cmd_group)
		return self._optimization

	@property
	def system(self):
		"""system commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_system'):
			from .System import SystemCls
			self._system = SystemCls(self._core, self._cmd_group)
		return self._system

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:AREGenerator:CHANnel:CATalog \n
		Snippet: value: List[str] = driver.source.areGenerator.channel.get_catalog() \n
		No command help available \n
			:return: areg_cconf_cat: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:CHANnel:CATalog?')
		return Conversions.str_to_str_list(response)

	def get_id(self) -> str:
		"""SCPI: [SOURce<HW>]:AREGenerator:CHANnel:ID \n
		Snippet: value: str = driver.source.areGenerator.channel.get_id() \n
		No command help available \n
			:return: areg_chan_id: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:CHANnel:ID?')
		return trim_str_response(response)

	def get_name(self) -> str:
		"""SCPI: [SOURce<HW>]:AREGenerator:CHANnel:NAME \n
		Snippet: value: str = driver.source.areGenerator.channel.get_name() \n
		Sets the alias of the radar channel, that is the channel name. \n
			:return: areg_channel_name: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:CHANnel:NAME?')
		return trim_str_response(response)

	def set_name(self, areg_channel_name: str) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:CHANnel:NAME \n
		Snippet: driver.source.areGenerator.channel.set_name(areg_channel_name = '1') \n
		Sets the alias of the radar channel, that is the channel name. \n
			:param areg_channel_name: string
		"""
		param = Conversions.value_to_quoted_str(areg_channel_name)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:CHANnel:NAME {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:AREGenerator:CHANnel:[STATe] \n
		Snippet: value: bool = driver.source.areGenerator.channel.get_state() \n
		Acitvates the radar channel. \n
			:return: areg_chan_state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:CHANnel:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, areg_chan_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:CHANnel:[STATe] \n
		Snippet: driver.source.areGenerator.channel.set_state(areg_chan_state = False) \n
		Acitvates the radar channel. \n
			:param areg_chan_state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(areg_chan_state)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:CHANnel:STATe {param}')

	def clone(self) -> 'ChannelCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ChannelCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SystemCls:
	"""System commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("system", core, parent)

	# noinspection PyTypeChecker
	def get_alignment(self) -> enums.AregCconfigSystAlign:
		"""SCPI: [SOURce<HW>]:AREGenerator:CHANnel:System:ALIGnment \n
		Snippet: value: enums.AregCconfigSystAlign = driver.source.areGenerator.channel.system.get_alignment() \n
		No command help available \n
			:return: syst_align: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:CHANnel:System:ALIGnment?')
		return Conversions.str_to_scalar_enum(response, enums.AregCconfigSystAlign)

	def set_alignment(self, syst_align: enums.AregCconfigSystAlign) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:CHANnel:System:ALIGnment \n
		Snippet: driver.source.areGenerator.channel.system.set_alignment(syst_align = enums.AregCconfigSystAlign.OFF) \n
		No command help available \n
			:param syst_align: No help available
		"""
		param = Conversions.enum_scalar_to_str(syst_align, enums.AregCconfigSystAlign)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:CHANnel:System:ALIGnment {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OptimizationCls:
	"""Optimization commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("optimization", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.AregCconfigOptMode:
		"""SCPI: [SOURce<HW>]:AREGenerator:CHANnel:OPTimization:MODE \n
		Snippet: value: enums.AregCconfigOptMode = driver.source.areGenerator.channel.optimization.get_mode() \n
		Selects the optimization mode of the radar channel. \n
			:return: areg_chan_mode: FAST| QHIG FAST Fast optimization mode This mode compensates I/Q skews and is suitable in time sensitive environments and for narrowband signals. QHIG High-quality optimization mode This mode compensates I/Q skews and uses frequency response correction data. The mode generates flat signals over large bandwidth but requires longer setting time and leads to signal interruption.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:CHANnel:OPTimization:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.AregCconfigOptMode)

	def set_mode(self, areg_chan_mode: enums.AregCconfigOptMode) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:CHANnel:OPTimization:MODE \n
		Snippet: driver.source.areGenerator.channel.optimization.set_mode(areg_chan_mode = enums.AregCconfigOptMode.FAST) \n
		Selects the optimization mode of the radar channel. \n
			:param areg_chan_mode: FAST| QHIG FAST Fast optimization mode This mode compensates I/Q skews and is suitable in time sensitive environments and for narrowband signals. QHIG High-quality optimization mode This mode compensates I/Q skews and uses frequency response correction data. The mode generates flat signals over large bandwidth but requires longer setting time and leads to signal interruption.
		"""
		param = Conversions.enum_scalar_to_str(areg_chan_mode, enums.AregCconfigOptMode)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:CHANnel:OPTimization:MODE {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DigHeadroomCls:
	"""DigHeadroom commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("digHeadroom", core, parent)

	def set(self, areg_adjust_dhead: int, mappingChannel=repcap.MappingChannel.Default) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:MAPPing<CH>:ADJust:LEVel:DIGHeadroom \n
		Snippet: driver.source.areGenerator.mapping.adjust.level.digHeadroom.set(areg_adjust_dhead = 1, mappingChannel = repcap.MappingChannel.Default) \n
		Sets the digital headroom of the channel output power. \n
			:param areg_adjust_dhead: integer Range: 0 to 30
			:param mappingChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mapping')
		"""
		param = Conversions.decimal_value_to_str(areg_adjust_dhead)
		mappingChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(mappingChannel, repcap.MappingChannel)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:MAPPing{mappingChannel_cmd_val}:ADJust:LEVel:DIGHeadroom {param}')

	def get(self, mappingChannel=repcap.MappingChannel.Default) -> int:
		"""SCPI: [SOURce<HW>]:AREGenerator:MAPPing<CH>:ADJust:LEVel:DIGHeadroom \n
		Snippet: value: int = driver.source.areGenerator.mapping.adjust.level.digHeadroom.get(mappingChannel = repcap.MappingChannel.Default) \n
		Sets the digital headroom of the channel output power. \n
			:param mappingChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mapping')
			:return: areg_adjust_dhead: integer Range: 0 to 30"""
		mappingChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(mappingChannel, repcap.MappingChannel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:AREGenerator:MAPPing{mappingChannel_cmd_val}:ADJust:LEVel:DIGHeadroom?')
		return Conversions.str_to_int(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SensorCls:
	"""Sensor commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sensor", core, parent)

	def set(self, areg_pow_sen_selec: enums.AregPowSens, trxFrontent=repcap.TrxFrontent.Default) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:FRONtend:TRX<CH>:EIRP:SENSor \n
		Snippet: driver.source.areGenerator.frontend.trx.eirp.sensor.set(areg_pow_sen_selec = enums.AregPowSens.SEN1, trxFrontent = repcap.TrxFrontent.Default) \n
		No command help available \n
			:param areg_pow_sen_selec: No help available
			:param trxFrontent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trx')
		"""
		param = Conversions.enum_scalar_to_str(areg_pow_sen_selec, enums.AregPowSens)
		trxFrontent_cmd_val = self._cmd_group.get_repcap_cmd_value(trxFrontent, repcap.TrxFrontent)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:FRONtend:TRX{trxFrontent_cmd_val}:EIRP:SENSor {param}')

	# noinspection PyTypeChecker
	def get(self, trxFrontent=repcap.TrxFrontent.Default) -> enums.AregPowSens:
		"""SCPI: [SOURce<HW>]:AREGenerator:FRONtend:TRX<CH>:EIRP:SENSor \n
		Snippet: value: enums.AregPowSens = driver.source.areGenerator.frontend.trx.eirp.sensor.get(trxFrontent = repcap.TrxFrontent.Default) \n
		No command help available \n
			:param trxFrontent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trx')
			:return: areg_pow_sen_selec: No help available"""
		trxFrontent_cmd_val = self._cmd_group.get_repcap_cmd_value(trxFrontent, repcap.TrxFrontent)
		response = self._core.io.query_str(f'SOURce<HwInstance>:AREGenerator:FRONtend:TRX{trxFrontent_cmd_val}:EIRP:SENSor?')
		return Conversions.str_to_scalar_enum(response, enums.AregPowSens)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SnumberCls:
	"""Snumber commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("snumber", core, parent)

	def set(self, areg_fe_ser_number: str, trxFrontent=repcap.TrxFrontent.Default) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:FRONtend:TRX<CH>:SNUMber \n
		Snippet: driver.source.areGenerator.frontend.trx.snumber.set(areg_fe_ser_number = '1', trxFrontent = repcap.TrxFrontent.Default) \n
		No command help available \n
			:param areg_fe_ser_number: string
			:param trxFrontent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trx')
		"""
		param = Conversions.value_to_quoted_str(areg_fe_ser_number)
		trxFrontent_cmd_val = self._cmd_group.get_repcap_cmd_value(trxFrontent, repcap.TrxFrontent)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:FRONtend:TRX{trxFrontent_cmd_val}:SNUMber {param}')

	def get(self, trxFrontent=repcap.TrxFrontent.Default) -> str:
		"""SCPI: [SOURce<HW>]:AREGenerator:FRONtend:TRX<CH>:SNUMber \n
		Snippet: value: str = driver.source.areGenerator.frontend.trx.snumber.get(trxFrontent = repcap.TrxFrontent.Default) \n
		No command help available \n
			:param trxFrontent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trx')
			:return: areg_fe_ser_number: string"""
		trxFrontent_cmd_val = self._cmd_group.get_repcap_cmd_value(trxFrontent, repcap.TrxFrontent)
		response = self._core.io.query_str(f'SOURce<HwInstance>:AREGenerator:FRONtend:TRX{trxFrontent_cmd_val}:SNUMber?')
		return trim_str_response(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MultiInstrumentCls:
	"""MultiInstrument commands group definition. 8 total commands, 2 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("multiInstrument", core, parent)

	@property
	def connect(self):
		"""connect commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_connect'):
			from .Connect import ConnectCls
			self._connect = ConnectCls(self._core, self._cmd_group)
		return self._connect

	@property
	def secondary(self):
		"""secondary commands group. 3 Sub-classes, 2 commands."""
		if not hasattr(self, '_secondary'):
			from .Secondary import SecondaryCls
			self._secondary = SecondaryCls(self._core, self._cmd_group)
		return self._secondary

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.AregMultiInstMode:
		"""SCPI: [SOURce<HW>]:AREGenerator:OSETup:MULTiinstrument:MODE \n
		Snippet: value: enums.AregMultiInstMode = driver.source.areGenerator.osetup.multiInstrument.get_mode() \n
		No command help available \n
			:return: mode: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:OSETup:MULTiinstrument:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.AregMultiInstMode)

	def set_mode(self, mode: enums.AregMultiInstMode) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:OSETup:MULTiinstrument:MODE \n
		Snippet: driver.source.areGenerator.osetup.multiInstrument.set_mode(mode = enums.AregMultiInstMode.OFF) \n
		No command help available \n
			:param mode: No help available
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.AregMultiInstMode)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:OSETup:MULTiinstrument:MODE {param}')

	def get_primary(self) -> str:
		"""SCPI: [SOURce<HW>]:AREGenerator:OSETup:MULTiinstrument:PRIMary \n
		Snippet: value: str = driver.source.areGenerator.osetup.multiInstrument.get_primary() \n
		No command help available \n
			:return: prim_syst_ctrl_add: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:OSETup:MULTiinstrument:PRIMary?')
		return trim_str_response(response)

	def set_primary(self, prim_syst_ctrl_add: str) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:OSETup:MULTiinstrument:PRIMary \n
		Snippet: driver.source.areGenerator.osetup.multiInstrument.set_primary(prim_syst_ctrl_add = '1') \n
		No command help available \n
			:param prim_syst_ctrl_add: No help available
		"""
		param = Conversions.value_to_quoted_str(prim_syst_ctrl_add)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:OSETup:MULTiinstrument:PRIMary {param}')

	def clone(self) -> 'MultiInstrumentCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = MultiInstrumentCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RangeCls:
	"""Range commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("range", core, parent)

	def get(self, objectIx=repcap.ObjectIx.Default) -> float:
		"""SCPI: [SOURce<HW>]:AREGenerator:OBJect<CH>:RANGe \n
		Snippet: value: float = driver.source.areGenerator.object.range.get(objectIx = repcap.ObjectIx.Default) \n
		Sets the range of the radar object. \n
			:param objectIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Object')
			:return: areg_obj_range: float Range: depends on settings to depends on settings"""
		objectIx_cmd_val = self._cmd_group.get_repcap_cmd_value(objectIx, repcap.ObjectIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:AREGenerator:OBJect{objectIx_cmd_val}:RANGe?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BwCls:
	"""Bw commands group definition. 3 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bw", core, parent)

	@property
	def discard(self):
		"""discard commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_discard'):
			from .Discard import DiscardCls
			self._discard = DiscardCls(self._core, self._cmd_group)
		return self._discard

	@property
	def exec(self):
		"""exec commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_exec'):
			from .Exec import ExecCls
			self._exec = ExecCls(self._core, self._cmd_group)
		return self._exec

	# noinspection PyTypeChecker
	def get_value(self) -> enums.AregCconfigBw:
		"""SCPI: [SOURce<HW>]:AREGenerator:CHANnel:BW \n
		Snippet: value: enums.AregCconfigBw = driver.source.areGenerator.channel.bw.get_value() \n
		No command help available \n
			:return: areg_chan_bw: BW1G| BW2G| BW5G
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:CHANnel:BW?')
		return Conversions.str_to_scalar_enum(response, enums.AregCconfigBw)

	def clone(self) -> 'BwCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = BwCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OffsetCls:
	"""Offset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("offset", core, parent)

	def set(self, areg_fe_ota_offset: int, trxFrontent=repcap.TrxFrontent.Default) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:FRONtend:TRX<CH>:OTA:OFFSet \n
		Snippet: driver.source.areGenerator.frontend.trx.ota.offset.set(areg_fe_ota_offset = 1, trxFrontent = repcap.TrxFrontent.Default) \n
		Specifies the length of the gap between frontend and target. \n
			:param areg_fe_ota_offset: integer Range: 0.01 to 10
			:param trxFrontent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trx')
		"""
		param = Conversions.decimal_value_to_str(areg_fe_ota_offset)
		trxFrontent_cmd_val = self._cmd_group.get_repcap_cmd_value(trxFrontent, repcap.TrxFrontent)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:FRONtend:TRX{trxFrontent_cmd_val}:OTA:OFFSet {param}')

	def get(self, trxFrontent=repcap.TrxFrontent.Default) -> int:
		"""SCPI: [SOURce<HW>]:AREGenerator:FRONtend:TRX<CH>:OTA:OFFSet \n
		Snippet: value: int = driver.source.areGenerator.frontend.trx.ota.offset.get(trxFrontent = repcap.TrxFrontent.Default) \n
		Specifies the length of the gap between frontend and target. \n
			:param trxFrontent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trx')
			:return: areg_fe_ota_offset: integer Range: 0.01 to 10"""
		trxFrontent_cmd_val = self._cmd_group.get_repcap_cmd_value(trxFrontent, repcap.TrxFrontent)
		response = self._core.io.query_str(f'SOURce<HwInstance>:AREGenerator:FRONtend:TRX{trxFrontent_cmd_val}:OTA:OFFSet?')
		return Conversions.str_to_int(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PositionCls:
	"""Position commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("position", core, parent)

	def get_actual(self) -> int:
		"""SCPI: [SOURce<HW>]:AREGenerator:SCENario:POSition:ACTual \n
		Snippet: value: int = driver.source.areGenerator.scenario.position.get_actual() \n
		No command help available \n
			:return: scen_act_pos: integer Range: 0 to 1E9
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:SCENario:POSition:ACTual?')
		return Conversions.str_to_int(response)

	def get_start(self) -> int:
		"""SCPI: [SOURce<HW>]:AREGenerator:SCENario:POSition:STARt \n
		Snippet: value: int = driver.source.areGenerator.scenario.position.get_start() \n
		No command help available \n
			:return: scen_start_pos: integer Range: 0 to 1E9
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:SCENario:POSition:STARt?')
		return Conversions.str_to_int(response)

	def set_start(self, scen_start_pos: int) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:SCENario:POSition:STARt \n
		Snippet: driver.source.areGenerator.scenario.position.set_start(scen_start_pos = 1) \n
		No command help available \n
			:param scen_start_pos: integer Range: 0 to 1E9
		"""
		param = Conversions.decimal_value_to_str(scen_start_pos)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:SCENario:POSition:STARt {param}')

	def get_stop(self) -> int:
		"""SCPI: [SOURce<HW>]:AREGenerator:SCENario:POSition:STOP \n
		Snippet: value: int = driver.source.areGenerator.scenario.position.get_stop() \n
		No command help available \n
			:return: scen_stop_pos: integer Range: 0 to 1E9
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:SCENario:POSition:STOP?')
		return Conversions.str_to_int(response)

	def set_stop(self, scen_stop_pos: int) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:SCENario:POSition:STOP \n
		Snippet: driver.source.areGenerator.scenario.position.set_stop(scen_stop_pos = 1) \n
		No command help available \n
			:param scen_stop_pos: integer Range: 0 to 1E9
		"""
		param = Conversions.decimal_value_to_str(scen_stop_pos)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:SCENario:POSition:STOP {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LevelCls:
	"""Level commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("level", core, parent)

	def get_measured(self) -> float:
		"""SCPI: [SOURce<HW>]:AREGenerator:CHANnel:LEVel:MEASured \n
		Snippet: value: float = driver.source.areGenerator.channel.level.get_measured() \n
		No command help available \n
			:return: areg_chan_level: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:CHANnel:LEVel:MEASured?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PowerCls:
	"""Power commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("power", core, parent)

	# noinspection PyTypeChecker
	def get_indicator(self) -> enums.AregRadarPowIndicator:
		"""SCPI: [SOURce<HW>]:AREGenerator:RADar:POWer:INDicator \n
		Snippet: value: enums.AregRadarPowIndicator = driver.source.areGenerator.radar.power.get_indicator() \n
		No command help available \n
			:return: pow_indicator: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:RADar:POWer:INDicator?')
		return Conversions.str_to_scalar_enum(response, enums.AregRadarPowIndicator)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, areg_fe_qat_mode: enums.AregFeQatMode, qatFrontent=repcap.QatFrontent.Default) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:FRONtend:QAT<CH>:MODE \n
		Snippet: driver.source.areGenerator.frontend.qat.mode.set(areg_fe_qat_mode = enums.AregFeQatMode.MULTi, qatFrontent = repcap.QatFrontent.Default) \n
		No command help available \n
			:param areg_fe_qat_mode: SINGle| MULTi
			:param qatFrontent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Qat')
		"""
		param = Conversions.enum_scalar_to_str(areg_fe_qat_mode, enums.AregFeQatMode)
		qatFrontent_cmd_val = self._cmd_group.get_repcap_cmd_value(qatFrontent, repcap.QatFrontent)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:FRONtend:QAT{qatFrontent_cmd_val}:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, qatFrontent=repcap.QatFrontent.Default) -> enums.AregFeQatMode:
		"""SCPI: [SOURce<HW>]:AREGenerator:FRONtend:QAT<CH>:MODE \n
		Snippet: value: enums.AregFeQatMode = driver.source.areGenerator.frontend.qat.mode.get(qatFrontent = repcap.QatFrontent.Default) \n
		No command help available \n
			:param qatFrontent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Qat')
			:return: areg_fe_qat_mode: SINGle| MULTi"""
		qatFrontent_cmd_val = self._cmd_group.get_repcap_cmd_value(qatFrontent, repcap.QatFrontent)
		response = self._core.io.query_str(f'SOURce<HwInstance>:AREGenerator:FRONtend:QAT{qatFrontent_cmd_val}:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.AregFeQatMode)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RadarCls:
	"""Radar commands group definition. 3 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("radar", core, parent)

	@property
	def base(self):
		"""base commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_base'):
			from .Base import BaseCls
			self._base = BaseCls(self._core, self._cmd_group)
		return self._base

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	def get_lsensitivity(self) -> bool:
		"""SCPI: [SOURce<HW>]:AREGenerator:RADar:LSENsitivity \n
		Snippet: value: bool = driver.source.areGenerator.radar.get_lsensitivity() \n
		No command help available \n
			:return: areg_radar_low_sen: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:RADar:LSENsitivity?')
		return Conversions.str_to_bool(response)

	def set_lsensitivity(self, areg_radar_low_sen: bool) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:RADar:LSENsitivity \n
		Snippet: driver.source.areGenerator.radar.set_lsensitivity(areg_radar_low_sen = False) \n
		No command help available \n
			:param areg_radar_low_sen: No help available
		"""
		param = Conversions.bool_to_str(areg_radar_low_sen)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:RADar:LSENsitivity {param}')

	def clone(self) -> 'RadarCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RadarCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.RepeatedCapability import RepeatedCapability
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class QatCls:
	"""Qat commands group definition. 29 total commands, 21 Subgroups, 0 group commands
	Repeated Capability: QatFrontent, default value after init: QatFrontent.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("qat", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_qatFrontent_get', 'repcap_qatFrontent_set', repcap.QatFrontent.Nr1)

	def repcap_qatFrontent_set(self, qatFrontent: repcap.QatFrontent) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to QatFrontent.Default
		Default value after init: QatFrontent.Nr1"""
		self._cmd_group.set_repcap_enum_value(qatFrontent)

	def repcap_qatFrontent_get(self) -> repcap.QatFrontent:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def add(self):
		"""add commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_add'):
			from .Add import AddCls
			self._add = AddCls(self._core, self._cmd_group)
		return self._add

	@property
	def alias(self):
		"""alias commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_alias'):
			from .Alias import AliasCls
			self._alias = AliasCls(self._core, self._cmd_group)
		return self._alias

	@property
	def ats(self):
		"""ats commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ats'):
			from .Ats import AtsCls
			self._ats = AtsCls(self._core, self._cmd_group)
		return self._ats

	@property
	def bw(self):
		"""bw commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bw'):
			from .Bw import BwCls
			self._bw = BwCls(self._core, self._cmd_group)
		return self._bw

	@property
	def cableCorr(self):
		"""cableCorr commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_cableCorr'):
			from .CableCorr import CableCorrCls
			self._cableCorr = CableCorrCls(self._core, self._cmd_group)
		return self._cableCorr

	@property
	def center(self):
		"""center commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_center'):
			from .Center import CenterCls
			self._center = CenterCls(self._core, self._cmd_group)
		return self._center

	@property
	def channels(self):
		"""channels commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_channels'):
			from .Channels import ChannelsCls
			self._channels = ChannelsCls(self._core, self._cmd_group)
		return self._channels

	@property
	def connect(self):
		"""connect commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_connect'):
			from .Connect import ConnectCls
			self._connect = ConnectCls(self._core, self._cmd_group)
		return self._connect

	@property
	def disconnect(self):
		"""disconnect commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_disconnect'):
			from .Disconnect import DisconnectCls
			self._disconnect = DisconnectCls(self._core, self._cmd_group)
		return self._disconnect

	@property
	def hostname(self):
		"""hostname commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hostname'):
			from .Hostname import HostnameCls
			self._hostname = HostnameCls(self._core, self._cmd_group)
		return self._hostname

	@property
	def id(self):
		"""id commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_id'):
			from .Id import IdCls
			self._id = IdCls(self._core, self._cmd_group)
		return self._id

	@property
	def ipAddress(self):
		"""ipAddress commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ipAddress'):
			from .IpAddress import IpAddressCls
			self._ipAddress = IpAddressCls(self._core, self._cmd_group)
		return self._ipAddress

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def name(self):
		"""name commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_name'):
			from .Name import NameCls
			self._name = NameCls(self._core, self._cmd_group)
		return self._name

	@property
	def offset(self):
		"""offset commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_offset'):
			from .Offset import OffsetCls
			self._offset = OffsetCls(self._core, self._cmd_group)
		return self._offset

	@property
	def ota(self):
		"""ota commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ota'):
			from .Ota import OtaCls
			self._ota = OtaCls(self._core, self._cmd_group)
		return self._ota

	@property
	def rmv(self):
		"""rmv commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rmv'):
			from .Rmv import RmvCls
			self._rmv = RmvCls(self._core, self._cmd_group)
		return self._rmv

	@property
	def rts(self):
		"""rts commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rts'):
			from .Rts import RtsCls
			self._rts = RtsCls(self._core, self._cmd_group)
		return self._rts

	@property
	def snumber(self):
		"""snumber commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_snumber'):
			from .Snumber import SnumberCls
			self._snumber = SnumberCls(self._core, self._cmd_group)
		return self._snumber

	@property
	def status(self):
		"""status commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_status'):
			from .Status import StatusCls
			self._status = StatusCls(self._core, self._cmd_group)
		return self._status

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePyCls
			self._typePy = TypePyCls(self._core, self._cmd_group)
		return self._typePy

	def clone(self) -> 'QatCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = QatCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, areg_fe_trx_an_cust: bool, trxFrontent=repcap.TrxFrontent.Default) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:FRONtend:TRX<CH>:ANTenna:CUSTom:[STATe] \n
		Snippet: driver.source.areGenerator.frontend.trx.antenna.custom.state.set(areg_fe_trx_an_cust = False, trxFrontent = repcap.TrxFrontent.Default) \n
		No command help available \n
			:param areg_fe_trx_an_cust: OFF| ON| 1| 0
			:param trxFrontent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trx')
		"""
		param = Conversions.bool_to_str(areg_fe_trx_an_cust)
		trxFrontent_cmd_val = self._cmd_group.get_repcap_cmd_value(trxFrontent, repcap.TrxFrontent)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:FRONtend:TRX{trxFrontent_cmd_val}:ANTenna:CUSTom:STATe {param}')

	def get(self, trxFrontent=repcap.TrxFrontent.Default) -> bool:
		"""SCPI: [SOURce<HW>]:AREGenerator:FRONtend:TRX<CH>:ANTenna:CUSTom:[STATe] \n
		Snippet: value: bool = driver.source.areGenerator.frontend.trx.antenna.custom.state.get(trxFrontent = repcap.TrxFrontent.Default) \n
		No command help available \n
			:param trxFrontent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trx')
			:return: areg_fe_trx_an_cust: OFF| ON| 1| 0"""
		trxFrontent_cmd_val = self._cmd_group.get_repcap_cmd_value(trxFrontent, repcap.TrxFrontent)
		response = self._core.io.query_str(f'SOURce<HwInstance>:AREGenerator:FRONtend:TRX{trxFrontent_cmd_val}:ANTenna:CUSTom:STATe?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LevelCls:
	"""Level commands group definition. 3 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("level", core, parent)

	@property
	def digHeadroom(self):
		"""digHeadroom commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_digHeadroom'):
			from .DigHeadroom import DigHeadroomCls
			self._digHeadroom = DigHeadroomCls(self._core, self._cmd_group)
		return self._digHeadroom

	@property
	def otime(self):
		"""otime commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_otime'):
			from .Otime import OtimeCls
			self._otime = OtimeCls(self._core, self._cmd_group)
		return self._otime

	def set(self, mappingChannel=repcap.MappingChannel.Default) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:MAPPing<CH>:ADJust:LEVel \n
		Snippet: driver.source.areGenerator.mapping.adjust.level.set(mappingChannel = repcap.MappingChannel.Default) \n
		Triggers adjustment of the power level of the selected output channels. \n
			:param mappingChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mapping')
		"""
		mappingChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(mappingChannel, repcap.MappingChannel)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:MAPPing{mappingChannel_cmd_val}:ADJust:LEVel')

	def set_with_opc(self, mappingChannel=repcap.MappingChannel.Default, opc_timeout_ms: int = -1) -> None:
		mappingChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(mappingChannel, repcap.MappingChannel)
		"""SCPI: [SOURce<HW>]:AREGenerator:MAPPing<CH>:ADJust:LEVel \n
		Snippet: driver.source.areGenerator.mapping.adjust.level.set_with_opc(mappingChannel = repcap.MappingChannel.Default) \n
		Triggers adjustment of the power level of the selected output channels. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsAreg800.utilities.opc_timeout_set() to set the timeout value. \n
			:param mappingChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mapping')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:AREGenerator:MAPPing{mappingChannel_cmd_val}:ADJust:LEVel', opc_timeout_ms)

	def clone(self) -> 'LevelCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = LevelCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



"""RsAreg800 instrument driver
	:version: 5.0.57.4
	:copyright: 2021 by Rohde & Schwarz GMBH & Co. KG
	:license: MIT, see LICENSE for more details.
"""

__version__ = '5.0.57.4'

# Main class
from RsAreg800.RsAreg800 import RsAreg800

# Bin data format
from RsAreg800.Internal.Conversions import BinIntFormat, BinFloatFormat

# Exceptions
from RsAreg800.Internal.InstrumentErrors import RsInstrException, TimeoutException, StatusException, UnexpectedResponseException, ResourceError, DriverValueError

# Callback Event Argument prototypes
from RsAreg800.Internal.IoTransferEventArgs import IoTransferEventArgs

# Logging Mode
from RsAreg800.Internal.ScpiLogger import LoggingMode

# enums
from RsAreg800 import enums

# repcaps
from RsAreg800 import repcap



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AllCls:
	"""All commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("all", core, parent)

	def set(self, mappingChannel=repcap.MappingChannel.Default) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:MAPPing<CH>:ADJust:ALL \n
		Snippet: driver.source.areGenerator.mapping.adjust.all.set(mappingChannel = repcap.MappingChannel.Default) \n
		Triggers adjustment of all power levels of the output channels. \n
			:param mappingChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mapping')
		"""
		mappingChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(mappingChannel, repcap.MappingChannel)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:MAPPing{mappingChannel_cmd_val}:ADJust:ALL')

	def set_with_opc(self, mappingChannel=repcap.MappingChannel.Default, opc_timeout_ms: int = -1) -> None:
		mappingChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(mappingChannel, repcap.MappingChannel)
		"""SCPI: [SOURce<HW>]:AREGenerator:MAPPing<CH>:ADJust:ALL \n
		Snippet: driver.source.areGenerator.mapping.adjust.all.set_with_opc(mappingChannel = repcap.MappingChannel.Default) \n
		Triggers adjustment of all power levels of the output channels. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsAreg800.utilities.opc_timeout_set() to set the timeout value. \n
			:param mappingChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mapping')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:AREGenerator:MAPPing{mappingChannel_cmd_val}:ADJust:ALL', opc_timeout_ms)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MeasurementCls:
	"""Measurement commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("measurement", core, parent)

	def get_keep_settings(self) -> bool:
		"""SCPI: [SOURce<HW>]:AREGenerator:MEASurement:KEEPsettings \n
		Snippet: value: bool = driver.source.areGenerator.measurement.get_keep_settings() \n
		No command help available \n
			:return: keep_settings: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:MEASurement:KEEPsettings?')
		return Conversions.str_to_bool(response)

	def set_keep_settings(self, keep_settings: bool) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:MEASurement:KEEPsettings \n
		Snippet: driver.source.areGenerator.measurement.set_keep_settings(keep_settings = False) \n
		No command help available \n
			:param keep_settings: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(keep_settings)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:MEASurement:KEEPsettings {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ButtonCls:
	"""Button commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("button", core, parent)

	def get_brightness(self) -> int:
		"""SCPI: DISPlay:BUTTon:BRIGhtness \n
		Snippet: value: int = driver.display.button.get_brightness() \n
		Sets the brightness of the [RF On/Off] key. \n
			:return: button_brightnes: integer Range: 1 to 20
		"""
		response = self._core.io.query_str('DISPlay:BUTTon:BRIGhtness?')
		return Conversions.str_to_int(response)

	def set_brightness(self, button_brightnes: int) -> None:
		"""SCPI: DISPlay:BUTTon:BRIGhtness \n
		Snippet: driver.display.button.set_brightness(button_brightnes = 1) \n
		Sets the brightness of the [RF On/Off] key. \n
			:param button_brightnes: integer Range: 1 to 20
		"""
		param = Conversions.decimal_value_to_str(button_brightnes)
		self._core.io.write(f'DISPlay:BUTTon:BRIGhtness {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SubnetCls:
	"""Subnet commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("subnet", core, parent)

	def get_mask(self) -> bytes:
		"""SCPI: SYSTem:COMMunicate:RT:NETWork:[IPADdress]:SUBNet:MASK \n
		Snippet: value: bytes = driver.system.communicate.rt.network.ipAddress.subnet.get_mask() \n
		Sets the subnet mask. \n
			:return: areg_zynq_net_sub_net_mask: No help available
		"""
		response = self._core.io.query_bin_block('SYSTem:COMMunicate:RT:NETWork:IPADdress:SUBNet:MASK?')
		return response

	def set_mask(self, areg_zynq_net_sub_net_mask: bytes) -> None:
		"""SCPI: SYSTem:COMMunicate:RT:NETWork:[IPADdress]:SUBNet:MASK \n
		Snippet: driver.system.communicate.rt.network.ipAddress.subnet.set_mask(areg_zynq_net_sub_net_mask = b'ABCDEFGH') \n
		Sets the subnet mask. \n
			:param areg_zynq_net_sub_net_mask: No help available
		"""
		self._core.io.write_bin_block('SYSTem:COMMunicate:RT:NETWork:IPADdress:SUBNet:MASK ', areg_zynq_net_sub_net_mask)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Types import DataType
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CustomizeCls:
	"""Customize commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("customize", core, parent)

	def set(self, board: str, index: int, sub_board: int) -> None:
		"""SCPI: DIAGnostic<HW>:EEPRom:CUSTomize \n
		Snippet: driver.diagnostic.eeprom.customize.set(board = '1', index = 1, sub_board = 1) \n
		No command help available \n
			:param board: No help available
			:param index: No help available
			:param sub_board: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('board', board, DataType.String), ArgSingle('index', index, DataType.Integer), ArgSingle('sub_board', sub_board, DataType.Integer))
		self._core.io.write(f'DIAGnostic<HwInstance>:EEPRom:CUSTomize {param}'.rstrip())



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IdCls:
	"""Id commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("id", core, parent)

	def set(self, areg_sconf_dyn_id: int, sensor=repcap.Sensor.Default) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:SENSor<CH>:DYNamic:ID \n
		Snippet: driver.source.areGenerator.sensor.dynamic.id.set(areg_sconf_dyn_id = 1, sensor = repcap.Sensor.Default) \n
		No command help available \n
			:param areg_sconf_dyn_id: No help available
			:param sensor: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sensor')
		"""
		param = Conversions.decimal_value_to_str(areg_sconf_dyn_id)
		sensor_cmd_val = self._cmd_group.get_repcap_cmd_value(sensor, repcap.Sensor)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:SENSor{sensor_cmd_val}:DYNamic:ID {param}')

	def get(self, sensor=repcap.Sensor.Default) -> int:
		"""SCPI: [SOURce<HW>]:AREGenerator:SENSor<CH>:DYNamic:ID \n
		Snippet: value: int = driver.source.areGenerator.sensor.dynamic.id.get(sensor = repcap.Sensor.Default) \n
		No command help available \n
			:param sensor: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sensor')
			:return: areg_sconf_dyn_id: No help available"""
		sensor_cmd_val = self._cmd_group.get_repcap_cmd_value(sensor, repcap.Sensor)
		response = self._core.io.query_str(f'SOURce<HwInstance>:AREGenerator:SENSor{sensor_cmd_val}:DYNamic:ID?')
		return Conversions.str_to_int(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CalibrationCls:
	"""Calibration commands group definition. 20 total commands, 7 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("calibration", core, parent)

	@property
	def all(self):
		"""all commands group. 1 Sub-classes, 4 commands."""
		if not hasattr(self, '_all'):
			from .All import AllCls
			self._all = AllCls(self._core, self._cmd_group)
		return self._all

	@property
	def data(self):
		"""data commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_data'):
			from .Data import DataCls
			self._data = DataCls(self._core, self._cmd_group)
		return self._data

	@property
	def frequency(self):
		"""frequency commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def level(self):
		"""level commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_level'):
			from .Level import LevelCls
			self._level = LevelCls(self._core, self._cmd_group)
		return self._level

	@property
	def roscillator(self):
		"""roscillator commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_roscillator'):
			from .Roscillator import RoscillatorCls
			self._roscillator = RoscillatorCls(self._core, self._cmd_group)
		return self._roscillator

	@property
	def selected(self):
		"""selected commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_selected'):
			from .Selected import SelectedCls
			self._selected = SelectedCls(self._core, self._cmd_group)
		return self._selected

	@property
	def tselected(self):
		"""tselected commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_tselected'):
			from .Tselected import TselectedCls
			self._tselected = TselectedCls(self._core, self._cmd_group)
		return self._tselected

	def get_continue_on_error(self) -> bool:
		"""SCPI: CALibration<HW>:CONTinueonerror \n
		Snippet: value: bool = driver.calibration.get_continue_on_error() \n
		Continues the calibration even though an error was detected. By default adjustments are aborted on error. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('CALibration<HwInstance>:CONTinueonerror?')
		return Conversions.str_to_bool(response)

	def set_continue_on_error(self, state: bool) -> None:
		"""SCPI: CALibration<HW>:CONTinueonerror \n
		Snippet: driver.calibration.set_continue_on_error(state = False) \n
		Continues the calibration even though an error was detected. By default adjustments are aborted on error. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'CALibration<HwInstance>:CONTinueonerror {param}')

	def set_debug(self, state: bool) -> None:
		"""SCPI: CALibration<HW>:DEBug \n
		Snippet: driver.calibration.set_debug(state = False) \n
		No command help available \n
			:param state: No help available
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'CALibration<HwInstance>:DEBug {param}')

	def clone(self) -> 'CalibrationCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CalibrationCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.RepeatedCapability import RepeatedCapability
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SensorCls:
	"""Sensor commands group definition. 11 total commands, 11 Subgroups, 0 group commands
	Repeated Capability: Sensor, default value after init: Sensor.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sensor", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_sensor_get', 'repcap_sensor_set', repcap.Sensor.Nr1)

	def repcap_sensor_set(self, sensor: repcap.Sensor) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Sensor.Default
		Default value after init: Sensor.Nr1"""
		self._cmd_group.set_repcap_enum_value(sensor)

	def repcap_sensor_get(self) -> repcap.Sensor:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def add(self):
		"""add commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_add'):
			from .Add import AddCls
			self._add = AddCls(self._core, self._cmd_group)
		return self._add

	@property
	def alias(self):
		"""alias commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_alias'):
			from .Alias import AliasCls
			self._alias = AliasCls(self._core, self._cmd_group)
		return self._alias

	@property
	def angle(self):
		"""angle commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_angle'):
			from .Angle import AngleCls
			self._angle = AngleCls(self._core, self._cmd_group)
		return self._angle

	@property
	def bw(self):
		"""bw commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bw'):
			from .Bw import BwCls
			self._bw = BwCls(self._core, self._cmd_group)
		return self._bw

	@property
	def center(self):
		"""center commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_center'):
			from .Center import CenterCls
			self._center = CenterCls(self._core, self._cmd_group)
		return self._center

	@property
	def count(self):
		"""count commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_count'):
			from .Count import CountCls
			self._count = CountCls(self._core, self._cmd_group)
		return self._count

	@property
	def distance(self):
		"""distance commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_distance'):
			from .Distance import DistanceCls
			self._distance = DistanceCls(self._core, self._cmd_group)
		return self._distance

	@property
	def dynamic(self):
		"""dynamic commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_dynamic'):
			from .Dynamic import DynamicCls
			self._dynamic = DynamicCls(self._core, self._cmd_group)
		return self._dynamic

	@property
	def eirp(self):
		"""eirp commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_eirp'):
			from .Eirp import EirpCls
			self._eirp = EirpCls(self._core, self._cmd_group)
		return self._eirp

	@property
	def id(self):
		"""id commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_id'):
			from .Id import IdCls
			self._id = IdCls(self._core, self._cmd_group)
		return self._id

	@property
	def rmv(self):
		"""rmv commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rmv'):
			from .Rmv import RmvCls
			self._rmv = RmvCls(self._core, self._cmd_group)
		return self._rmv

	def clone(self) -> 'SensorCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SensorCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EirpCls:
	"""Eirp commands group definition. 3 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("eirp", core, parent)

	@property
	def port(self):
		"""port commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_port'):
			from .Port import PortCls
			self._port = PortCls(self._core, self._cmd_group)
		return self._port

	@property
	def sensor(self):
		"""sensor commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sensor'):
			from .Sensor import SensorCls
			self._sensor = SensorCls(self._core, self._cmd_group)
		return self._sensor

	def get(self, trxFrontent=repcap.TrxFrontent.Default) -> float:
		"""SCPI: [SOURce<HW>]:AREGenerator:FRONtend:TRX<CH>:EIRP \n
		Snippet: value: float = driver.source.areGenerator.frontend.trx.eirp.get(trxFrontent = repcap.TrxFrontent.Default) \n
		No command help available \n
			:param trxFrontent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trx')
			:return: areg_radar_eirp: No help available"""
		trxFrontent_cmd_val = self._cmd_group.get_repcap_cmd_value(trxFrontent, repcap.TrxFrontent)
		response = self._core.io.query_str(f'SOURce<HwInstance>:AREGenerator:FRONtend:TRX{trxFrontent_cmd_val}:EIRP?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'EirpCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = EirpCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RmvCls:
	"""Rmv commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rmv", core, parent)

	def set(self, sensor=repcap.Sensor.Default) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:SENSor<CH>:RMV \n
		Snippet: driver.source.areGenerator.sensor.rmv.set(sensor = repcap.Sensor.Default) \n
		No command help available \n
			:param sensor: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sensor')
		"""
		sensor_cmd_val = self._cmd_group.get_repcap_cmd_value(sensor, repcap.Sensor)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:SENSor{sensor_cmd_val}:RMV')

	def set_with_opc(self, sensor=repcap.Sensor.Default, opc_timeout_ms: int = -1) -> None:
		sensor_cmd_val = self._cmd_group.get_repcap_cmd_value(sensor, repcap.Sensor)
		"""SCPI: [SOURce<HW>]:AREGenerator:SENSor<CH>:RMV \n
		Snippet: driver.source.areGenerator.sensor.rmv.set_with_opc(sensor = repcap.Sensor.Default) \n
		No command help available \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsAreg800.utilities.opc_timeout_set() to set the timeout value. \n
			:param sensor: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sensor')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:AREGenerator:SENSor{sensor_cmd_val}:RMV', opc_timeout_ms)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FrontendCls:
	"""Frontend commands group definition. 57 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("frontend", core, parent)

	@property
	def last(self):
		"""last commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_last'):
			from .Last import LastCls
			self._last = LastCls(self._core, self._cmd_group)
		return self._last

	@property
	def qat(self):
		"""qat commands group. 21 Sub-classes, 0 commands."""
		if not hasattr(self, '_qat'):
			from .Qat import QatCls
			self._qat = QatCls(self._core, self._cmd_group)
		return self._qat

	@property
	def trx(self):
		"""trx commands group. 15 Sub-classes, 0 commands."""
		if not hasattr(self, '_trx'):
			from .Trx import TrxCls
			self._trx = TrxCls(self._core, self._cmd_group)
		return self._trx

	def clone(self) -> 'FrontendCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FrontendCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ReplayCls:
	"""Replay commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("replay", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.ScenarioReplyMode:
		"""SCPI: [SOURce<HW>]:AREGenerator:SCENario:REPLay:[MODE] \n
		Snippet: value: enums.ScenarioReplyMode = driver.source.areGenerator.scenario.replay.get_mode() \n
		No command help available \n
			:return: scen_reply_mode: SINGle| LOOP
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:SCENario:REPLay:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.ScenarioReplyMode)

	def set_mode(self, scen_reply_mode: enums.ScenarioReplyMode) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:SCENario:REPLay:[MODE] \n
		Snippet: driver.source.areGenerator.scenario.replay.set_mode(scen_reply_mode = enums.ScenarioReplyMode.LOOP) \n
		No command help available \n
			:param scen_reply_mode: SINGle| LOOP
		"""
		param = Conversions.enum_scalar_to_str(scen_reply_mode, enums.ScenarioReplyMode)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:SCENario:REPLay:MODE {param}')



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class InvalidCls:
	"""Invalid commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("invalid", core, parent)

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:AREGenerator:OBJects:INValid:CATalog \n
		Snippet: value: List[str] = driver.source.areGenerator.objects.invalid.get_catalog() \n
		No command help available \n
			:return: areg_obj_invalid_cat: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:OBJects:INValid:CATalog?')
		return Conversions.str_to_str_list(response)

	def get_value(self) -> int:
		"""SCPI: [SOURce<HW>]:AREGenerator:OBJects:INValid \n
		Snippet: value: int = driver.source.areGenerator.objects.invalid.get_value() \n
		Specifies the number of invalid radar objects for a specific channel. \n
			:return: numb_of_invalid_ob: integer Range: 0 to 8
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:OBJects:INValid?')
		return Conversions.str_to_int(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HilCls:
	"""Hil commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("hil", core, parent)

	def get_rate(self) -> float:
		"""SCPI: [SOURce<HW>]:AREGenerator:HIL:RATE \n
		Snippet: value: float = driver.source.areGenerator.hil.get_rate() \n
		No command help available \n
			:return: hil: float Range: 0 to 1E9
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:HIL:RATE?')
		return Conversions.str_to_float(response)

	# noinspection PyTypeChecker
	def get_received(self) -> enums.HilDataReceive:
		"""SCPI: [SOURce<HW>]:AREGenerator:HIL:RECeived \n
		Snippet: value: enums.HilDataReceive = driver.source.areGenerator.hil.get_received() \n
		No command help available \n
			:return: hil_data_received: NOData| RECeived| NOTHil
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:HIL:RECeived?')
		return Conversions.str_to_scalar_enum(response, enums.HilDataReceive)

	def set_received(self, hil_data_received: enums.HilDataReceive) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:HIL:RECeived \n
		Snippet: driver.source.areGenerator.hil.set_received(hil_data_received = enums.HilDataReceive.NOData) \n
		No command help available \n
			:param hil_data_received: NOData| RECeived| NOTHil
		"""
		param = Conversions.enum_scalar_to_str(hil_data_received, enums.HilDataReceive)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:HIL:RECeived {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ExternalCls:
	"""External commands group definition. 3 total commands, 1 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("external", core, parent)

	@property
	def rfOff(self):
		"""rfOff commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rfOff'):
			from .RfOff import RfOffCls
			self._rfOff = RfOffCls(self._core, self._cmd_group)
		return self._rfOff

	# noinspection PyTypeChecker
	def get_frequency(self) -> enums.RoscFreqExt:
		"""SCPI: [SOURce]:ROSCillator:EXTernal:FREQuency \n
		Snippet: value: enums.RoscFreqExt = driver.source.roscillator.external.get_frequency() \n
		Sets the frequency of the external reference. \n
			:return: frequency: 100MHZ| 1GHZ| VARiable| 10MHZ
		"""
		response = self._core.io.query_str('SOURce:ROSCillator:EXTernal:FREQuency?')
		return Conversions.str_to_scalar_enum(response, enums.RoscFreqExt)

	def set_frequency(self, frequency: enums.RoscFreqExt) -> None:
		"""SCPI: [SOURce]:ROSCillator:EXTernal:FREQuency \n
		Snippet: driver.source.roscillator.external.set_frequency(frequency = enums.RoscFreqExt._10MHZ) \n
		Sets the frequency of the external reference. \n
			:param frequency: 100MHZ| 1GHZ| VARiable| 10MHZ
		"""
		param = Conversions.enum_scalar_to_str(frequency, enums.RoscFreqExt)
		self._core.io.write(f'SOURce:ROSCillator:EXTernal:FREQuency {param}')

	# noinspection PyTypeChecker
	def get_sbandwidth(self) -> enums.RoscBandWidtExt:
		"""SCPI: [SOURce]:ROSCillator:EXTernal:SBANdwidth \n
		Snippet: value: enums.RoscBandWidtExt = driver.source.roscillator.external.get_sbandwidth() \n
		Selects the synchronization bandwidth for the external reference signal. Depending on the RF hardware version, and the
		installed options, the synchronizsation bandwidth varies. For more information, see data sheet. \n
			:return: sbandwidth: WIDE| NARRow NARRow The synchronization bandwidth is a few Hz. WIDE Uses the widest possible synchronization bandwidth.
		"""
		response = self._core.io.query_str('SOURce:ROSCillator:EXTernal:SBANdwidth?')
		return Conversions.str_to_scalar_enum(response, enums.RoscBandWidtExt)

	def set_sbandwidth(self, sbandwidth: enums.RoscBandWidtExt) -> None:
		"""SCPI: [SOURce]:ROSCillator:EXTernal:SBANdwidth \n
		Snippet: driver.source.roscillator.external.set_sbandwidth(sbandwidth = enums.RoscBandWidtExt.NARRow) \n
		Selects the synchronization bandwidth for the external reference signal. Depending on the RF hardware version, and the
		installed options, the synchronizsation bandwidth varies. For more information, see data sheet. \n
			:param sbandwidth: WIDE| NARRow NARRow The synchronization bandwidth is a few Hz. WIDE Uses the widest possible synchronization bandwidth.
		"""
		param = Conversions.enum_scalar_to_str(sbandwidth, enums.RoscBandWidtExt)
		self._core.io.write(f'SOURce:ROSCillator:EXTernal:SBANdwidth {param}')

	def clone(self) -> 'ExternalCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ExternalCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FrequencyCls:
	"""Frequency commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("frequency", core, parent)

	def set(self, frequency: float, channel=repcap.Channel.Default) -> None:
		"""SCPI: SENSe<CH>:[POWer]:FREQuency \n
		Snippet: driver.sense.power.frequency.set(frequency = 1.0, channel = repcap.Channel.Default) \n
		Sets the RF frequency of the signal, if signal source 'USER' is selected (method RsAreg800.Sense.Power.Source.set) . \n
			:param frequency: float
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sense')
		"""
		param = Conversions.decimal_value_to_str(frequency)
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SENSe{channel_cmd_val}:POWer:FREQuency {param}')

	def get(self, channel=repcap.Channel.Default) -> float:
		"""SCPI: SENSe<CH>:[POWer]:FREQuency \n
		Snippet: value: float = driver.sense.power.frequency.get(channel = repcap.Channel.Default) \n
		Sets the RF frequency of the signal, if signal source 'USER' is selected (method RsAreg800.Sense.Power.Source.set) . \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sense')
			:return: frequency: float"""
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SENSe{channel_cmd_val}:POWer:FREQuency?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CountCls:
	"""Count commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("count", core, parent)

	def get(self, sensor=repcap.Sensor.Default) -> int:
		"""SCPI: [SOURce<HW>]:AREGenerator:SENSor<CH>:COUNt \n
		Snippet: value: int = driver.source.areGenerator.sensor.count.get(sensor = repcap.Sensor.Default) \n
		No command help available \n
			:param sensor: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sensor')
			:return: areg_sensor_count: No help available"""
		sensor_cmd_val = self._cmd_group.get_repcap_cmd_value(sensor, repcap.Sensor)
		response = self._core.io.query_str(f'SOURce<HwInstance>:AREGenerator:SENSor{sensor_cmd_val}:COUNt?')
		return Conversions.str_to_int(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DistanceCls:
	"""Distance commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("distance", core, parent)

	def set(self, areg_fe_dist_offset: float, qatFrontent=repcap.QatFrontent.Default) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:FRONtend:QAT<CH>:OFFSet:DISTance \n
		Snippet: driver.source.areGenerator.frontend.qat.offset.distance.set(areg_fe_dist_offset = 1.0, qatFrontent = repcap.QatFrontent.Default) \n
		No command help available \n
			:param areg_fe_dist_offset: float Range: -1000 to 1000
			:param qatFrontent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Qat')
		"""
		param = Conversions.decimal_value_to_str(areg_fe_dist_offset)
		qatFrontent_cmd_val = self._cmd_group.get_repcap_cmd_value(qatFrontent, repcap.QatFrontent)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:FRONtend:QAT{qatFrontent_cmd_val}:OFFSet:DISTance {param}')

	def get(self, qatFrontent=repcap.QatFrontent.Default) -> float:
		"""SCPI: [SOURce<HW>]:AREGenerator:FRONtend:QAT<CH>:OFFSet:DISTance \n
		Snippet: value: float = driver.source.areGenerator.frontend.qat.offset.distance.get(qatFrontent = repcap.QatFrontent.Default) \n
		No command help available \n
			:param qatFrontent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Qat')
			:return: areg_fe_dist_offset: float Range: -1000 to 1000"""
		qatFrontent_cmd_val = self._cmd_group.get_repcap_cmd_value(qatFrontent, repcap.QatFrontent)
		response = self._core.io.query_str(f'SOURce<HwInstance>:AREGenerator:FRONtend:QAT{qatFrontent_cmd_val}:OFFSet:DISTance?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ConnectionCls:
	"""Connection commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("connection", core, parent)

	# noinspection PyTypeChecker
	def get_state(self) -> enums.AregMultiInstCnctStatus:
		"""SCPI: [SOURce<HW>]:AREGenerator:OSETup:MULTiinstrument:SECondary:CONNection:[STATe] \n
		Snippet: value: enums.AregMultiInstCnctStatus = driver.source.areGenerator.osetup.multiInstrument.secondary.connection.get_state() \n
		No command help available \n
			:return: conn_state: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:OSETup:MULTiinstrument:SECondary:CONNection:STATe?')
		return Conversions.str_to_scalar_enum(response, enums.AregMultiInstCnctStatus)



from typing import List

from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PowerCls:
	"""Power commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("power", core, parent)

	def get(self, channel=repcap.Channel.Default) -> List[float]:
		"""SCPI: READ<CH>:[POWer] \n
		Snippet: value: List[float] = driver.read.power.get(channel = repcap.Channel.Default) \n
		Triggers power measurement and displays the results. Note: This command does not affect the local state, i.e. you can get
		results with local state on or off. For long measurement times, we recommend that you use an SRQ for command
		synchronization (MAV bit) . \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Read')
			:return: power: float or float,float The sensor returns the result in the unit set with command method RsAreg800.Sense.Unit.Power.set Certain power sensors, such as the R&S NRP-Z81, return two values, first the value of the average level and - separated by a comma - the peak value."""
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_bin_or_ascii_float_list(f'READ{channel_cmd_val}:POWer?')
		return response



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TxCls:
	"""Tx commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tx", core, parent)

	def set(self, areg_fe_trx_gain_tx: float, trxFrontent=repcap.TrxFrontent.Default) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:FRONtend:TRX<CH>:ANTenna:GAIN:TX \n
		Snippet: driver.source.areGenerator.frontend.trx.antenna.gain.tx.set(areg_fe_trx_gain_tx = 1.0, trxFrontent = repcap.TrxFrontent.Default) \n
		No command help available \n
			:param areg_fe_trx_gain_tx: float Range: 0 to 30
			:param trxFrontent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trx')
		"""
		param = Conversions.decimal_value_to_str(areg_fe_trx_gain_tx)
		trxFrontent_cmd_val = self._cmd_group.get_repcap_cmd_value(trxFrontent, repcap.TrxFrontent)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:FRONtend:TRX{trxFrontent_cmd_val}:ANTenna:GAIN:TX {param}')

	def get(self, trxFrontent=repcap.TrxFrontent.Default) -> float:
		"""SCPI: [SOURce<HW>]:AREGenerator:FRONtend:TRX<CH>:ANTenna:GAIN:TX \n
		Snippet: value: float = driver.source.areGenerator.frontend.trx.antenna.gain.tx.get(trxFrontent = repcap.TrxFrontent.Default) \n
		No command help available \n
			:param trxFrontent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trx')
			:return: areg_fe_trx_gain_tx: float Range: 0 to 30"""
		trxFrontent_cmd_val = self._cmd_group.get_repcap_cmd_value(trxFrontent, repcap.TrxFrontent)
		response = self._core.io.query_str(f'SOURce<HwInstance>:AREGenerator:FRONtend:TRX{trxFrontent_cmd_val}:ANTenna:GAIN:TX?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DayCls:
	"""Day commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("day", core, parent)

	def get_state(self) -> bool:
		"""SCPI: HCOPy:FILE:[NAME]:AUTO:[FILE]:DAY:STATe \n
		Snippet: value: bool = driver.hardCopy.file.name.auto.file.day.get_state() \n
		Uses the date parameters (year, month or day) for the automatic naming. You can activate each of the date parameters
		separately. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('HCOPy:FILE:NAME:AUTO:FILE:DAY:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: HCOPy:FILE:[NAME]:AUTO:[FILE]:DAY:STATe \n
		Snippet: driver.hardCopy.file.name.auto.file.day.set_state(state = False) \n
		Uses the date parameters (year, month or day) for the automatic naming. You can activate each of the date parameters
		separately. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'HCOPy:FILE:NAME:AUTO:FILE:DAY:STATe {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DistanceCls:
	"""Distance commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("distance", core, parent)

	def set(self, areg_sens_sto_distance: int, sensor=repcap.Sensor.Default) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:SENSor<CH>:DISTance \n
		Snippet: driver.source.areGenerator.sensor.distance.set(areg_sens_sto_distance = 1, sensor = repcap.Sensor.Default) \n
		No command help available \n
			:param areg_sens_sto_distance: integer Range: -50 to 150
			:param sensor: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sensor')
		"""
		param = Conversions.decimal_value_to_str(areg_sens_sto_distance)
		sensor_cmd_val = self._cmd_group.get_repcap_cmd_value(sensor, repcap.Sensor)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:SENSor{sensor_cmd_val}:DISTance {param}')

	def get(self, sensor=repcap.Sensor.Default) -> int:
		"""SCPI: [SOURce<HW>]:AREGenerator:SENSor<CH>:DISTance \n
		Snippet: value: int = driver.source.areGenerator.sensor.distance.get(sensor = repcap.Sensor.Default) \n
		No command help available \n
			:param sensor: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sensor')
			:return: areg_sens_sto_distance: integer Range: -50 to 150"""
		sensor_cmd_val = self._cmd_group.get_repcap_cmd_value(sensor, repcap.Sensor)
		response = self._core.io.query_str(f'SOURce<HwInstance>:AREGenerator:SENSor{sensor_cmd_val}:DISTance?')
		return Conversions.str_to_int(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ScenarioCls:
	"""Scenario commands group definition. 12 total commands, 4 Subgroups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("scenario", core, parent)

	@property
	def file(self):
		"""file commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_file'):
			from .File import FileCls
			self._file = FileCls(self._core, self._cmd_group)
		return self._file

	@property
	def pause(self):
		"""pause commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pause'):
			from .Pause import PauseCls
			self._pause = PauseCls(self._core, self._cmd_group)
		return self._pause

	@property
	def position(self):
		"""position commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_position'):
			from .Position import PositionCls
			self._position = PositionCls(self._core, self._cmd_group)
		return self._position

	@property
	def replay(self):
		"""replay commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_replay'):
			from .Replay import ReplayCls
			self._replay = ReplayCls(self._core, self._cmd_group)
		return self._replay

	def get_progress(self) -> float:
		"""SCPI: [SOURce<HW>]:AREGenerator:SCENario:PROGress \n
		Snippet: value: float = driver.source.areGenerator.scenario.get_progress() \n
		No command help available \n
			:return: scenario_progres: float Range: 0 to 100
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:SCENario:PROGress?')
		return Conversions.str_to_float(response)

	def set_progress(self, scenario_progres: float) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:SCENario:PROGress \n
		Snippet: driver.source.areGenerator.scenario.set_progress(scenario_progres = 1.0) \n
		No command help available \n
			:param scenario_progres: float Range: 0 to 100
		"""
		param = Conversions.decimal_value_to_str(scenario_progres)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:SCENario:PROGress {param}')

	def reset(self) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:SCENario:RESet \n
		Snippet: driver.source.areGenerator.scenario.reset() \n
		No command help available \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:SCENario:RESet')

	def reset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:SCENario:RESet \n
		Snippet: driver.source.areGenerator.scenario.reset_with_opc() \n
		No command help available \n
		Same as reset, but waits for the operation to complete before continuing further. Use the RsAreg800.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:AREGenerator:SCENario:RESet', opc_timeout_ms)

	def start(self) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:SCENario:STARt \n
		Snippet: driver.source.areGenerator.scenario.start() \n
		No command help available \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:SCENario:STARt')

	def start_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:SCENario:STARt \n
		Snippet: driver.source.areGenerator.scenario.start_with_opc() \n
		No command help available \n
		Same as start, but waits for the operation to complete before continuing further. Use the RsAreg800.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:AREGenerator:SCENario:STARt', opc_timeout_ms)

	# noinspection PyTypeChecker
	def get_status(self) -> enums.ScenarioStatus:
		"""SCPI: [SOURce<HW>]:AREGenerator:SCENario:STATus \n
		Snippet: value: enums.ScenarioStatus = driver.source.areGenerator.scenario.get_status() \n
		No command help available \n
			:return: scenario_status: RUNNing| STOPped
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:SCENario:STATus?')
		return Conversions.str_to_scalar_enum(response, enums.ScenarioStatus)

	def set_status(self, scenario_status: enums.ScenarioStatus) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:SCENario:STATus \n
		Snippet: driver.source.areGenerator.scenario.set_status(scenario_status = enums.ScenarioStatus.RUNNing) \n
		No command help available \n
			:param scenario_status: RUNNing| STOPped
		"""
		param = Conversions.enum_scalar_to_str(scenario_status, enums.ScenarioStatus)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:SCENario:STATus {param}')

	def stop(self) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:SCENario:STOP \n
		Snippet: driver.source.areGenerator.scenario.stop() \n
		No command help available \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:SCENario:STOP')

	def stop_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:SCENario:STOP \n
		Snippet: driver.source.areGenerator.scenario.stop_with_opc() \n
		No command help available \n
		Same as stop, but waits for the operation to complete before continuing further. Use the RsAreg800.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:AREGenerator:SCENario:STOP', opc_timeout_ms)

	def clone(self) -> 'ScenarioCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ScenarioCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FrequencyCls:
	"""Frequency commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("frequency", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.RoscOutpFreqModeSmbb:
		"""SCPI: [SOURce]:ROSCillator:OUTPut:FREQuency:MODE \n
		Snippet: value: enums.RoscOutpFreqModeSmbb = driver.source.roscillator.output.frequency.get_mode() \n
		Selects the mode for the output reference frequency. \n
			:return: outp_freq_mode: DER10M| OFF DER10M Sets the output reference frequency to 10 MHz. The reference frequency is derived from the internal reference frequency. OFF Disables the output.
		"""
		response = self._core.io.query_str('SOURce:ROSCillator:OUTPut:FREQuency:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.RoscOutpFreqModeSmbb)

	def set_mode(self, outp_freq_mode: enums.RoscOutpFreqModeSmbb) -> None:
		"""SCPI: [SOURce]:ROSCillator:OUTPut:FREQuency:MODE \n
		Snippet: driver.source.roscillator.output.frequency.set_mode(outp_freq_mode = enums.RoscOutpFreqModeSmbb.DER10M) \n
		Selects the mode for the output reference frequency. \n
			:param outp_freq_mode: DER10M| OFF DER10M Sets the output reference frequency to 10 MHz. The reference frequency is derived from the internal reference frequency. OFF Disables the output.
		"""
		param = Conversions.enum_scalar_to_str(outp_freq_mode, enums.RoscOutpFreqModeSmbb)
		self._core.io.write(f'SOURce:ROSCillator:OUTPut:FREQuency:MODE {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PrefixCls:
	"""Prefix commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("prefix", core, parent)

	def get_state(self) -> bool:
		"""SCPI: HCOPy:FILE:[NAME]:AUTO:[FILE]:PREFix:STATe \n
		Snippet: value: bool = driver.hardCopy.file.name.auto.file.prefix.get_state() \n
		Uses the prefix for the automatic generation of the file name, provided PREF:STAT is activated. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('HCOPy:FILE:NAME:AUTO:FILE:PREFix:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: HCOPy:FILE:[NAME]:AUTO:[FILE]:PREFix:STATe \n
		Snippet: driver.hardCopy.file.name.auto.file.prefix.set_state(state = False) \n
		Uses the prefix for the automatic generation of the file name, provided PREF:STAT is activated. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'HCOPy:FILE:NAME:AUTO:FILE:PREFix:STATe {param}')

	def get_value(self) -> str:
		"""SCPI: HCOPy:FILE:[NAME]:AUTO:[FILE]:PREFix \n
		Snippet: value: str = driver.hardCopy.file.name.auto.file.prefix.get_value() \n
		Uses the prefix for the automatic generation of the file name, provided PREF:STAT is activated. \n
			:return: prefix: No help available
		"""
		response = self._core.io.query_str('HCOPy:FILE:NAME:AUTO:FILE:PREFix?')
		return trim_str_response(response)

	def set_value(self, prefix: str) -> None:
		"""SCPI: HCOPy:FILE:[NAME]:AUTO:[FILE]:PREFix \n
		Snippet: driver.hardCopy.file.name.auto.file.prefix.set_value(prefix = '1') \n
		Uses the prefix for the automatic generation of the file name, provided PREF:STAT is activated. \n
			:param prefix: 0| 1| OFF| ON
		"""
		param = Conversions.value_to_quoted_str(prefix)
		self._core.io.write(f'HCOPy:FILE:NAME:AUTO:FILE:PREFix {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, areg_fconf_type: enums.AregFeType, qatFrontent=repcap.QatFrontent.Default) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:FRONtend:QAT<CH>:TYPE \n
		Snippet: driver.source.areGenerator.frontend.qat.typePy.set(areg_fconf_type = enums.AregFeType.NONE, qatFrontent = repcap.QatFrontent.Default) \n
		No command help available \n
			:param areg_fconf_type: TRX| QAT| NONE
			:param qatFrontent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Qat')
		"""
		param = Conversions.enum_scalar_to_str(areg_fconf_type, enums.AregFeType)
		qatFrontent_cmd_val = self._cmd_group.get_repcap_cmd_value(qatFrontent, repcap.QatFrontent)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:FRONtend:QAT{qatFrontent_cmd_val}:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self, qatFrontent=repcap.QatFrontent.Default) -> enums.AregFeType:
		"""SCPI: [SOURce<HW>]:AREGenerator:FRONtend:QAT<CH>:TYPE \n
		Snippet: value: enums.AregFeType = driver.source.areGenerator.frontend.qat.typePy.get(qatFrontent = repcap.QatFrontent.Default) \n
		No command help available \n
			:param qatFrontent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Qat')
			:return: areg_fconf_type: TRX| QAT| NONE"""
		qatFrontent_cmd_val = self._cmd_group.get_repcap_cmd_value(qatFrontent, repcap.QatFrontent)
		response = self._core.io.query_str(f'SOURce<HwInstance>:AREGenerator:FRONtend:QAT{qatFrontent_cmd_val}:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.AregFeType)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, areg_cabel_cor_mod: enums.AregCableCorrSour, qatFrontent=repcap.QatFrontent.Default, connector=repcap.Connector.Default, txIndexNull=repcap.TxIndexNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:FRONtend:QAT<CH>:CABLecorr:CONNector<DI>:TX<ST0>:MODE \n
		Snippet: driver.source.areGenerator.frontend.qat.cableCorr.connector.tx.mode.set(areg_cabel_cor_mod = enums.AregCableCorrSour.S2P, qatFrontent = repcap.QatFrontent.Default, connector = repcap.Connector.Default, txIndexNull = repcap.TxIndexNull.Default) \n
		No command help available \n
			:param areg_cabel_cor_mod: USER| S2P
			:param qatFrontent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Qat')
			:param connector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Connector')
			:param txIndexNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Tx')
		"""
		param = Conversions.enum_scalar_to_str(areg_cabel_cor_mod, enums.AregCableCorrSour)
		qatFrontent_cmd_val = self._cmd_group.get_repcap_cmd_value(qatFrontent, repcap.QatFrontent)
		connector_cmd_val = self._cmd_group.get_repcap_cmd_value(connector, repcap.Connector)
		txIndexNull_cmd_val = self._cmd_group.get_repcap_cmd_value(txIndexNull, repcap.TxIndexNull)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:FRONtend:QAT{qatFrontent_cmd_val}:CABLecorr:CONNector{connector_cmd_val}:TX{txIndexNull_cmd_val}:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, qatFrontent=repcap.QatFrontent.Default, connector=repcap.Connector.Default, txIndexNull=repcap.TxIndexNull.Default) -> enums.AregCableCorrSour:
		"""SCPI: [SOURce<HW>]:AREGenerator:FRONtend:QAT<CH>:CABLecorr:CONNector<DI>:TX<ST0>:MODE \n
		Snippet: value: enums.AregCableCorrSour = driver.source.areGenerator.frontend.qat.cableCorr.connector.tx.mode.get(qatFrontent = repcap.QatFrontent.Default, connector = repcap.Connector.Default, txIndexNull = repcap.TxIndexNull.Default) \n
		No command help available \n
			:param qatFrontent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Qat')
			:param connector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Connector')
			:param txIndexNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Tx')
			:return: areg_cabel_cor_mod: USER| S2P"""
		qatFrontent_cmd_val = self._cmd_group.get_repcap_cmd_value(qatFrontent, repcap.QatFrontent)
		connector_cmd_val = self._cmd_group.get_repcap_cmd_value(connector, repcap.Connector)
		txIndexNull_cmd_val = self._cmd_group.get_repcap_cmd_value(txIndexNull, repcap.TxIndexNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:AREGenerator:FRONtend:QAT{qatFrontent_cmd_val}:CABLecorr:CONNector{connector_cmd_val}:TX{txIndexNull_cmd_val}:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.AregCableCorrSour)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ConditionCls:
	"""Condition commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("condition", core, parent)

	def get_info(self) -> str:
		"""SCPI: [SOURce<HW>]:AREGenerator:CHANnel:CONDition:INFO \n
		Snippet: value: str = driver.source.areGenerator.channel.condition.get_info() \n
		No command help available \n
			:return: areg_pow_led_info: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:CHANnel:CONDition:INFO?')
		return trim_str_response(response)

	def set_info(self, areg_pow_led_info: str) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:CHANnel:CONDition:INFO \n
		Snippet: driver.source.areGenerator.channel.condition.set_info(areg_pow_led_info = '1') \n
		No command help available \n
			:param areg_pow_led_info: string
		"""
		param = Conversions.value_to_quoted_str(areg_pow_led_info)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:CHANnel:CONDition:INFO {param}')

	# noinspection PyTypeChecker
	def get_value(self) -> enums.AregPlEd:
		"""SCPI: [SOURce<HW>]:AREGenerator:CHANnel:CONDition \n
		Snippet: value: enums.AregPlEd = driver.source.areGenerator.channel.condition.get_value() \n
		No command help available \n
			:return: areg_pow_led_statu: INACtive| WARNing| ERRor| OK
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:CHANnel:CONDition?')
		return Conversions.str_to_scalar_enum(response, enums.AregPlEd)

	def set_value(self, areg_pow_led_statu: enums.AregPlEd) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:CHANnel:CONDition \n
		Snippet: driver.source.areGenerator.channel.condition.set_value(areg_pow_led_statu = enums.AregPlEd.ERRor) \n
		No command help available \n
			:param areg_pow_led_statu: INACtive| WARNing| ERRor| OK
		"""
		param = Conversions.enum_scalar_to_str(areg_pow_led_statu, enums.AregPlEd)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:CHANnel:CONDition {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DcatalogCls:
	"""Dcatalog commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dcatalog", core, parent)

	@property
	def length(self):
		"""length commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_length'):
			from .Length import LengthCls
			self._length = LengthCls(self._core, self._cmd_group)
		return self._length

	def get_value(self) -> str:
		"""SCPI: MMEMory:DCATalog \n
		Snippet: value: str = driver.massMemory.dcatalog.get_value() \n
		Returns the subdirectories of a particular directory. \n
			:return: dcatalog: No help available
		"""
		response = self._core.io.query_str('MMEMory:DCATalog?')
		return trim_str_response(response)

	def clone(self) -> 'DcatalogCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DcatalogCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LastCls:
	"""Last commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("last", core, parent)

	def get_sensor(self) -> int:
		"""SCPI: [SOURce<HW>]:AREGenerator:LAST:SENSor \n
		Snippet: value: int = driver.source.areGenerator.last.get_sensor() \n
		No command help available \n
			:return: areg_last_sensor: integer Range: 0 to 8
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:LAST:SENSor?')
		return Conversions.str_to_int(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AllCls:
	"""All commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("all", core, parent)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:AREGenerator:OBJect:ALL:[STATe] \n
		Snippet: value: bool = driver.source.areGenerator.object.all.get_state() \n
		Activates all available radar objects for a specific channel. \n
			:return: global_obj_stat: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:AREGenerator:OBJect:ALL:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, global_obj_stat: bool) -> None:
		"""SCPI: [SOURce<HW>]:AREGenerator:OBJect:ALL:[STATe] \n
		Snippet: driver.source.areGenerator.object.all.set_state(global_obj_stat = False) \n
		Activates all available radar objects for a specific channel. \n
			:param global_obj_stat: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(global_obj_stat)
		self._core.io.write(f'SOURce<HwInstance>:AREGenerator:OBJect:ALL:STATe {param}')
